@@ -1,41 +1,85 @@
-mmer <- function(Y, X=NULL, Z=NULL, W=NULL, R=NULL, method="AI", REML=TRUE, iters=30, draw=FALSE, init=NULL, n.PC=0, P3D=TRUE, models="additive", ploidy=2, min.MAF=0.05, silent=FALSE, family=NULL, constraint=TRUE, sherman=FALSE, EIGEND=FALSE, Fishers=FALSE, gss=TRUE, forced=NULL, full.rank=TRUE, map=NULL, fdr.level=0.05, manh.col=NULL, gwas.plots=TRUE, n.cores=1,lmerHELP=FALSE){
+mmer <- function(Y, X=NULL, Z=NULL, W=NULL, R=NULL, method="AI", REML=TRUE, MVM=FALSE, iters=30, draw=FALSE, init=NULL, n.PC=0, P3D=TRUE, models="additive", ploidy=2, min.MAF=0.05, silent=FALSE, family=NULL, constraint=TRUE, sherman=FALSE, EIGEND=FALSE, Fishers=FALSE, gss=TRUE, forced=NULL, full.rank=TRUE, map=NULL, fdr.level=0.05, manh.col=NULL, gwas.plots=TRUE, n.cores=1,lmerHELP=FALSE, tolpar = 1e-06, tolparinv = 1e-06){
   diso <- dim(as.data.frame(Y))[2]
   
+  my.month <- 7 #version of the month
+  datee <- Sys.Date()
+  both <- as.numeric(strsplit(gsub("....-","",datee),"-")[[1]])
+  month <- both[1]#your month
+  ## if your month is greater than my month you are outdated
+  if(month > my.month){
+    cat("Version out of date. Please update sommer to the newest version using:\ninstall.packages('sommer') in a new session\n")
+  }
   #########*****************************
   #########*****************************
   if(diso > 1){ # IF MULTIPLE RESPONSES
-    NC <- detectCores() #parallel package
     
-    #######$$$$$$$$$$$$$$$$$$$$$$$$$$$
-    #######$$$$$$$$$$$$$$$$$$$$$$$$$$$
-    if(n.cores > NC){ # USER USE MORE CORES THAN AVAILABLE
-      stop(paste("You are selecting more cores than the",NC,"available in your computer"),call.=FALSE)
-    }else{ # USER SELECTS LESS OR ENOUGH CORES THAN AVAILABLE
+    if(MVM){ # if MULTIVARIATE
+      method="EMMAM"
+      if(!is.null(X)){
+        if(is.list(X)){
+          stop("Multivariate models only accept one incidence matrix for fixed effects (X). Please modifiy your X argument.",call. = FALSE)
+        }
+      }
+      if(!silent){cat("Running multivariate model")}
+      RES <- MMERM(Y=Y, X=X, Z=Z, method=method, silent=silent, tolpar = tolpar, tolparinv = tolparinv)
+      class(RES)<-c("MMERM")
+    }else{ # if UNIVARIATE IN PARALLEL
+      #######$$$$$$$$$$$$$$$$$$$$$$$$$$$
+      #######$$$$$$$$$$$$$$$$$$$$$$$$$$$
+      NC <- detectCores() #parallel package
       
-      ######^^^^^^^^^^^^^^^^^^^^^^^
-      ######^^^^^^^^^^^^^^^^^^^^^^^
-      if(NC >= n.cores){ # there's still more cores available than selected or enough
+      if(n.cores > NC){ # USER USE MORE CORES THAN AVAILABLE
+        stop(paste("You are selecting more cores than the",NC,"available in your computer"),call.=FALSE)
+      }else{ # USER SELECTS LESS OR ENOUGH CORES THAN AVAILABLE
         
-        if(diso > n.cores){ # and user has more responses than cores used
-          cat(paste("Cores used in your computer:",n.cores, "of", NC,"\nFeel free to modify the 'n.core' argument to run each response in parallel.\nArguments 'draw', 'gwas.plots' will be set to FALSE")) 
+        ######^^^^^^^^^^^^^^^^^^^^^^^
+        ######^^^^^^^^^^^^^^^^^^^^^^^
+        
+        if(NC >= n.cores){ # there's still more cores available than selected or enough
           
-          i=NULL
-          cl <- makeCluster(n.cores) # Make clusters registerDoSNOW(cl)
-          RES <- foreach (i=1:diso) %dopar% mmerSNOW(y=Y[,i], X=X, Z=Z, R=R, W=W, method=method, REML=REML, iters=iters, draw=FALSE, init=init, silent=TRUE, constraint=constraint, sherman=sherman, EIGEND=EIGEND, gss=gss, forced=forced, map=map, fdr.level=fdr.level, manh.col=manh.col,gwas.plots=FALSE,lmerHELP=lmerHELP)
-          stopCluster(cl)
-          names(RES) <- colnames(Y)
-          class(RES)<-c("mmerM")
-          
-        }else{ # user has the same or less responses that the #of cores he is using
-          
-          cat(paste("Cores used in your computer:",n.cores, "for", diso,"responses.\nArguments 'draw', 'gwas.plots' will be set to FALSE"))
-          i=NULL
-          cl <- makeCluster(n.cores) # Make clusters registerDoSNOW(cl)
-          RES <- foreach (i=1:diso) %dopar% mmerSNOW(y=Y[,i], X=X, Z=Z, R=R, W=W, method=method, REML=REML, iters=iters, draw=FALSE, init=init, silent=TRUE, constraint=constraint, sherman=sherman, EIGEND=EIGEND, gss=gss, forced=forced, map=map, fdr.level=fdr.level, manh.col=manh.col,gwas.plots=FALSE,lmerHELP=lmerHELP)
-          stopCluster(cl)
-          names(RES) <- colnames(Y)
-          class(RES)<-c("mmerM")
-          #RES$multi <- "M2"
+          if(diso > n.cores){ # and user has more responses than cores used
+            cat(paste("Cores used in your computer:",n.cores, "out of", NC,"\nFeel free to modify the 'n.cores' argument to run faster parallel models.\nFor running the model as multivariate set the argument 'MVM=TRUE'\nArguments; 'draw' and 'gwas.plots' will be set to FALSE")) 
+            
+            
+            Y <- as.list((Y))
+            Y <- lapply(Y, function(x){as.matrix(x)})
+            ########################################################################
+            ## if user wants to change the fixed effects for the parallelized models
+            if(is.list(X)){
+              if(length(X) != diso){
+                stop("If you specify multiple fixed effect matrices (X), \nit has to be the same number than responses provided.",call. = FALSE)
+              }
+              WORK <- apply(data.frame(1:diso),1,function(x,y,z){cbind(y[[x]],z[[x]])},y=Y,z=X)
+              RES <- mclapply(WORK,function(x){ mmerSNOW(y=x[,1], X=x[,-1], Z=Z, R=R, W=W, method=method, REML=REML, iters=iters, draw=FALSE, init=init, silent=TRUE, constraint=constraint, sherman=sherman, EIGEND=EIGEND, gss=gss, forced=forced, map=map, fdr.level=fdr.level, manh.col=manh.col,gwas.plots=FALSE,lmerHELP=lmerHELP)}, mc.cores=n.cores)
+            }else{ # user just provide a single fixed effect matrix
+              RES <- mclapply(Y,function(x){ mmerSNOW(y=x[,1], X=X, Z=Z, R=R, W=W, method=method, REML=REML, iters=iters, draw=FALSE, init=init, silent=TRUE, constraint=constraint, sherman=sherman, EIGEND=EIGEND, gss=gss, forced=forced, map=map, fdr.level=fdr.level, manh.col=manh.col,gwas.plots=FALSE,lmerHELP=lmerHELP)}, mc.cores=n.cores)
+            }
+            ########################################################################
+            names(RES) <- names(Y)
+            class(RES)<-c("mmerM")
+            
+          }else{ # user has the same or less responses that the #of cores he is using
+            
+            cat(paste("Cores used in your computer:",n.cores, "for", diso,"responses.\nFor running the model as multivariate set the argument 'MVM=TRUE'\nArguments 'draw', 'gwas.plots' will be set to FALSE"))
+            
+            Y <- as.list(Y)
+            Y <- lapply(Y, function(x){as.matrix(x)})
+            ########################################################################
+            ## if user wants to change the fixed effects for the parallelized models
+            if(is.list(X)){
+              if(length(X) != diso){
+                stop("If you specify multiple fixed effect matrices (X), \nit has to be the same number than responses provided.",call. = FALSE)
+              }
+              WORK <- apply(data.frame(1:diso),1,function(x,y,z){cbind(y[[x]],z[[x]])},y=Y,z=X)
+              RES <- mclapply(WORK,function(x){ mmerSNOW(y=x[,1], X=x[,-1], Z=Z, R=R, W=W, method=method, REML=REML, iters=iters, draw=FALSE, init=init, silent=TRUE, constraint=constraint, sherman=sherman, EIGEND=EIGEND, gss=gss, forced=forced, map=map, fdr.level=fdr.level, manh.col=manh.col,gwas.plots=FALSE,lmerHELP=lmerHELP)}, mc.cores=n.cores)
+            }else{ # user just provide a single fixed effect matrix
+              RES <- mclapply(Y,function(x){ mmerSNOW(y=x[,1], X=X, Z=Z, R=R, W=W, method=method, REML=REML, iters=iters, draw=FALSE, init=init, silent=TRUE, constraint=constraint, sherman=sherman, EIGEND=EIGEND, gss=gss, forced=forced, map=map, fdr.level=fdr.level, manh.col=manh.col,gwas.plots=FALSE,lmerHELP=lmerHELP)}, mc.cores=n.cores)
+            }
+            ########################################################################
+            names(RES) <- names(Y)
+            class(RES)<-c("mmerM")
+            #RES$multi <- "M2"
+          }
         }
       }
     }
@@ -45,14 +89,10 @@ mmer <- function(Y, X=NULL, Z=NULL, W=NULL, R=NULL, method="AI", REML=TRUE, iter
     
   }else{ ## ONE RESPONSE
     RES <- mmerSNOW(y=Y, X=X, Z=Z, R=R, W=W, method=method, REML=REML, iters=iters, draw=draw, init=init, silent=silent, constraint=constraint, sherman=sherman, EIGEND=EIGEND, gss=gss, forced=forced, map=map, fdr.level=fdr.level, manh.col=manh.col,gwas.plots=gwas.plots,lmerHELP=lmerHELP)
-    #RES$multi <- "M1"
   }
   #########*****************************
   #########*****************************
   
-  ### "M1" is univariate
-  ### "M2" is univariate run in parallel
-  ### "M3" is multivariate run
   return(RES)
 }
 
@@ -62,7 +102,7 @@ mmer <- function(Y, X=NULL, Z=NULL, W=NULL, R=NULL, method="AI", REML=TRUE, iter
 #### =========== ####
 "summary.mmer" <- function(object, ...) {
   digits = max(3, getOption("digits") - 3)
-  groupss <- unlist(lapply(object$u.hat, function(y){dim(y)[1]}))
+  groupss <- unlist(lapply(object$u.hat, function(y){dim(as.matrix(y))[1]}))
   groupss <- paste(groupss,collapse = " ")
   nn <- length(unlist(object$residuals))
   #cat("Linear mixed model fit by restricted maximum likelihood\n")
@@ -116,7 +156,7 @@ mmer <- function(Y, X=NULL, Z=NULL, W=NULL, R=NULL, method="AI", REML=TRUE, iter
   cat("\nInformation contained in this fitted model: \n* Variance components\n* Residuals and conditional residuals\n* BLUEs and BLUPs\n* Inverse phenotypic variance(V)\n* Variance-covariance matrix for fixed effects\n* Variance-covariance matrix for random effects\n* Predicted error variance (PEV)\n* LogLikelihood\n* AIC and BIC\n* Fitted values\nUse the 'str' function to access such information\n")
   cat("\n=======================================================")
   cat("\nLinear mixed model fit by restricted maximum likelihood\n")
-  cat("********************  sommer 1.8  *********************\n")
+  cat("********************  sommer 1.9  *********************\n")
   cat("=======================================================")
   cat("\nMethod:")
   print(x$method)
@@ -159,61 +199,120 @@ mmer <- function(Y, X=NULL, Z=NULL, W=NULL, R=NULL, method="AI", REML=TRUE, iter
 "summary.mmerM" <- function(object, ...) {
   
   
-    digits = max(3, getOption("digits") - 3)
-    #forget <- length(object)
-    
-    groupss.nn <- cbind(
-      do.call("rbind",lapply(object,function(x){lapply(x$u.hat, function(y){dim(y)[1]})})),
-      do.call("rbind",lapply(object,function(x){length(unlist(x$residuals))}))
-    ); 
-    groupss.nn <- t(groupss.nn);
-    
-    if(is.null(rownames(groupss.nn))){
-      re <- 1:(dim(groupss.nn)[1] - 1) # random effects
-      rownames(groupss.nn) <- c(paste("Groups.u",re,sep="."),"No.obs")
-    }else{
-      rownames(groupss.nn)[dim(groupss.nn)[1]] <- c("No.obs")
-    }
-    
-    
-    
-    method=object[[1]]$method
-    #cat("\n")
-    
-    LLAIC <- rbind(do.call("cbind",lapply(object,function(x){x$LL})),
-    do.call("cbind",lapply(object,function(x){x$AIC})),
-    do.call("cbind",lapply(object,function(x){x$BIC}))
-    )
-    
-    rownames(LLAIC) = c("logLik","AIC","BIC")
-    
-    w <- do.call("cbind",lapply(object,function(x){x$var.comp}))
-    colnames(w) <- names(object)
-    output <- list(groupss=groupss.nn, logo=LLAIC, w=w, method=method)
-    attr(output, "class")<-c("summary.mmerM", "list")
+  digits = max(3, getOption("digits") - 3)
+  #forget <- length(object)
+  
+  groupss.nn <- cbind(
+    do.call("rbind",lapply(object,function(x){lapply(x$u.hat, function(y){dim(y)[1]})})),
+    do.call("rbind",lapply(object,function(x){length(unlist(x$residuals))}))
+  ); 
+  groupss.nn <- t(groupss.nn);
+  
+  if(is.null(rownames(groupss.nn))){
+    re <- 1:(dim(groupss.nn)[1] - 1) # random effects
+    rownames(groupss.nn) <- c(paste("Groups.u",re,sep="."),"No.obs")
+  }else{
+    rownames(groupss.nn)[dim(groupss.nn)[1]] <- c("No.obs")
+  }
+  
+  
+  
+  method=object[[1]]$method
+  #cat("\n")
+  
+  LLAIC <- rbind(do.call("cbind",lapply(object,function(x){x$LL})),
+                 do.call("cbind",lapply(object,function(x){x$AIC})),
+                 do.call("cbind",lapply(object,function(x){x$BIC}))
+  )
+  
+  rownames(LLAIC) = c("logLik","AIC","BIC")
+  
+  w <- do.call("cbind",lapply(object,function(x){x$var.comp}))
+  colnames(w) <- names(object)
+  output <- list(groupss=groupss.nn, logo=LLAIC, w=w, method=method)
+  attr(output, "class")<-c("summary.mmerM", "list")
   return(output)
 }
 
 "print.summary.mmerM"<-function (x, digits = max(3, getOption("digits") - 3),  ...){
   
-    digits = max(3, getOption("digits") - 3)
-    cat("Information contained in this structure: \n* Individual results for each response model\nDisplayed: \n* AIC and BIC summaries\n* Variance component summaries\nUse the '$' sign to access individual models\n")
-    cat("=======================================================")
-    cat("\nLinear mixed model fit by restricted maximum likelihood\n")
-    cat("********************  sommer 1.8  *********************\n")
-    cat("=======================================================")
-    cat("\nMethod:")
-    print(x$method)
-    cat("")
-    print(x$logo)#, digits = digits)
-    cat("=======================================================")
-    cat("\nVariance components:\n")
-    print(x$w, digits = digits)
-    cat("=======================================================")
-    cat("\nGroups and observations\n")
-    print(x$groupss, digits = digits)
-    cat("=======================================================")
-    cat("\nUse the '$' sign to access individual models\nYou can use 'summary' on individual models\nArguments set to FALSE for multiple models:\n'draw' and 'gwas.plots'\n")
+  digits = max(3, getOption("digits") - 3)
+  cat("Information contained in this structure: \n* Individual results for each response model\nDisplayed: \n* AIC and BIC summaries\n* Variance component summaries\nUse the '$' sign to access individual models\n")
+  cat("=======================================================")
+  cat("\nLinear mixed model fit by restricted maximum likelihood\n")
+  cat("********************  sommer 1.9  *********************\n")
+  cat("=======================================================")
+  cat("\nMethod:")
+  print(x$method)
+  cat("")
+  print(x$logo)#, digits = digits)
+  cat("=======================================================")
+  cat("\nVariance components:\n")
+  print(x$w, digits = digits)
+  cat("=======================================================")
+  cat("\nGroups and observations\n")
+  print(x$groupss, digits = digits)
+  cat("=======================================================")
+  cat("\nUse the '$' sign to access individual models\nYou can use 'summary' on individual models\nArguments set to FALSE for multiple models:\n'draw' and 'gwas.plots'\n")
+}
+
+#### =========== ####
+## SUMMARY FUNCTION MMERM #
+#### =========== ####
+"summary.MMERM" <- function(object, ...) {
+  
+  dim(object$Gpred)
+  digits = max(3, getOption("digits") - 3)
+  #forget <- length(object)
+  
+  groupss.nn <- t(as.matrix(object$dimos))
+  
+  colnames(groupss.nn) <- c("Observ","Groups")
+  
+  nano <- names(object$ZETA)[1]
+  if(!is.null(nano)){
+    rownames(groupss.nn) <- nano
+    names(object$var.comp)[1] <- paste("Var-Covar(",nano,")",sep="")
+    names(object$var.comp)[2] <- "Var-Covar(Error)"
+  }else{
+    rownames(groupss.nn) <- "u.1"
+  }
+  
+  
+  method=object$method
+  
+  w <- object$var.comp
+  output <- list(groupss=groupss.nn, w=w, method=method)
+  attr(output, "class")<-c("summary.MMERM", "list")
+  return(output)
+}
+
+"print.summary.MMERM"<-function (x, digits = max(3, getOption("digits") - 3),  ...){
+  
+  digits = max(3, getOption("digits") - 3)
+  cat("Information contained in this structure: \n* Results for a multi response model\nDisplayed: \n* Variance-covariance component summaries\nUse the '$' sign to access parameters\n")
+  cat("=======================================================")
+  cat("\nLinear mixed model fit by restricted maximum likelihood\n")
+  cat("********************  sommer 1.9  *********************\n")
+  cat("=======================================================")
+  cat("\nMethod:")
+  print(x$method)
+  cat("")
+  cat("=======================================================")
+  cat("\nVariance-Covariance components:\n\n")
+  
+  for(h in 1:length(x$w)){
+    cat(paste(names(x$w)[h],"\n"))
+    print(x$w[[h]], digits = digits)
+    if(h!= length(x$w)){
+      cat("\n")
+    }
+  }
+  cat("=======================================================")
+  cat("\nGroups and observations\n")
+  print(x$groupss, digits = digits)
+  cat("=======================================================")
+  cat("\nUse the '$' sign to access parameters\nArguments set to FALSE for multiresponse models:\n'draw', 'W', and 'gwas.plots'\n")
 }
 
 #### =========== ######
@@ -236,7 +335,7 @@ mmer <- function(Y, X=NULL, Z=NULL, W=NULL, R=NULL, method="AI", REML=TRUE, iter
 
 "residuals.mmerM" <- function(object, type="conditional", ...) {
   digits = max(3, getOption("digits") - 3)
-
+  
   if(type=="conditional"){
     output<-do.call("cbind",lapply(object,function(x){x$cond.residuals}))
     colnames(output) <- names(object)
@@ -251,6 +350,22 @@ mmer <- function(Y, X=NULL, Z=NULL, W=NULL, R=NULL, method="AI", REML=TRUE, iter
   print((x))
 }
 
+"residuals.MMERM" <- function(object, type="conditional", ...) {
+  digits = max(3, getOption("digits") - 3)
+  
+  if(type=="conditional"){
+    output <- object$cond.residuals
+    #colnames(output) <- names(object)
+  }else{
+    output<- output <- object$residuals
+    #colnames(output) <- names(object)
+  }
+  return(output)
+}
+
+"print.residuals.MMERM"<- function(x, digits = max(3, getOption("digits") - 3), ...) {
+  print((x))
+}
 #### =========== ######
 ## RANEF FUNCTION #
 #### =========== ######
@@ -263,8 +378,11 @@ mmer <- function(Y, X=NULL, Z=NULL, W=NULL, R=NULL, method="AI", REML=TRUE, iter
   }else if(class(object)=="mmer"){
     digits = max(3, getOption("digits") - 3)
     output <- object$u.hat
+  }else if(class(object)=="MMERM"){
+    digits = max(3, getOption("digits") - 3)
+    output <- object$u.hat
   }
-
+  
   return(output)
 }
 
@@ -275,26 +393,36 @@ mmer <- function(Y, X=NULL, Z=NULL, W=NULL, R=NULL, method="AI", REML=TRUE, iter
 #### =========== ######
 ## FIXEF FUNCTION #
 #### =========== ######
-"fixef.mmer" <- function(object, ...) {
-  digits = max(3, getOption("digits") - 3)
-  output <- object$beta.hat
-  return(output)
-}
+#"fixef.mmer" <- function(object, ...) {
+#  digits = max(3, getOption("digits") - 3)
+#  output <- object$beta.hat
+#  return(output)
+#}
 
-"print.fixef.mmer"<- function(x, digits = max(3, getOption("digits") - 3), ...) {
-  print((x))
-}
+#"print.fixef.mmer"<- function(x, digits = max(3, getOption("digits") - 3), ...) {
+#  print((x))
+#}
 
-"fixef.mmerM" <- function(object, ...) {
-  digits = max(3, getOption("digits") - 3)
-  output<-do.call("cbind",lapply(object,function(x){x$beta.hat}))
-  colnames(output) <- names(object)
-  return(output)
-}
+#"fixef.MMERM" <- function(object, ...) {
+#  digits = max(3, getOption("digits") - 3)
+#  output <- object$beta.hat
+#  return(output)
+#}
 
-"print.fixef.mmerM"<- function(x, digits = max(3, getOption("digits") - 3), ...) {
-  print((x))
-}
+#"print.fixef.MMERM"<- function(x, digits = max(3, getOption("digits") - 3), ...) {
+#  print((x))
+#}
+
+#"fixef.mmerM" <- function(object, ...) {
+#  digits = max(3, getOption("digits") - 3)
+#  output<-do.call("cbind",lapply(object,function(x){x$beta.hat}))
+#  colnames(output) <- names(object)
+#  return(output)
+#}
+
+#"print.fixef.mmerM"<- function(x, digits = max(3, getOption("digits") - 3), ...) {
+#  print((x))
+#}
 
 #### =========== ####
 ## FITTED FUNCTION ##
@@ -329,6 +457,26 @@ mmer <- function(Y, X=NULL, Z=NULL, W=NULL, R=NULL, method="AI", REML=TRUE, iter
 "print.fitted.mmerM"<- function(x, digits = max(3, getOption("digits") - 3), ...) {
   print((x))
 } 
+
+
+"fitted.MMERM" <- function(object, type="complete", ...) {
+  #type="complete" 
+  digits = max(3, getOption("digits") - 3)
+  if(type=="complete"){
+    output<- object$fitted.y
+    #colnames(output) <- names(object)
+  }else{
+    output<- object$fitted.u
+    #colnames(output) <- names(object)
+  }
+  return(output)
+}
+
+"print.fitted.MMERM"<- function(x, digits = max(3, getOption("digits") - 3), ...) {
+  print((x))
+} 
+
+
 #### =========== ####
 ## COEF FUNCTION ####
 #### =========== ####
@@ -340,6 +488,14 @@ mmer <- function(Y, X=NULL, Z=NULL, W=NULL, R=NULL, method="AI", REML=TRUE, iter
   print((x))
 } 
 
+"coef.MMERM" <- function(object, ...){
+  object$beta.hat
+}
+
+"print.coef.MMERM"<- function(x, digits = max(3, getOption("digits") - 3), ...) {
+  print((x))
+} 
+
 "coef.mmerM" <- function(object, ...){
   output<-do.call("cbind",lapply(object,function(x){x$beta.hat}))
   colnames(output) <- names(object)
@@ -411,6 +567,10 @@ anova.mmer <- function(object, object2=NULL, ...) {
 anova.mmerM <- function(object, object2=NULL, ...) {
   cat("'anova' function only works for individual models to perform likelihood ratio tests (LRT).\nYou can access individuals models using the '$' sign and then use 'anova'.")
 }
+
+anova.MMERM <- function(object, object2=NULL, ...) {
+  cat("'anova' function only works for individual models to perform likelihood ratio tests (LRT).\nCurrently is not enabled for multivariate models.")
+}
 #### =========== ####
 ## PLOTING FUNCTION #
 #### =========== ####
@@ -434,6 +594,10 @@ plot.mmer <- function(x, ...) {
 plot.mmerM <- function(x, ...) {
   cat("'plot' function only works for individual models to check diagnostic plots.\nYou can access individuals models using the '$' sign and then use 'plot'.")
 }
+
+plot.MMERM <- function(x, ...) {
+  cat("'plot' function only works for individual models not for multi-reponse models.")
+}
 ##################################################################################################
 #Startup function
 #this function is executed once the library is loaded
@@ -444,7 +608,7 @@ plot.mmerM <- function(x, ...) {
     stop("This package requires R 2.1 or later")
   assign(".sommer.home", file.path(library, pkg),
          pos=match("package:sommer", search()))
-  sommer.version = "1.8 (2016-06-06)"
+  sommer.version = "1.9 (2016-07-01)"
   
   ##%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   ### check which version is more recent
@@ -464,14 +628,12 @@ plot.mmerM <- function(x, ...) {
     packageStartupMessage(paste("# Solving Mixed Model Equations in R (sommer) ", sommer.version, ". ",sep=""),appendLF=TRUE)
     packageStartupMessage(paste("# Mixed models allowing covariance structures in random effects"),appendLF=TRUE)
     packageStartupMessage("# Author: Giovanny Covarrubias-Pazaran",appendLF=TRUE)
-    packageStartupMessage("# Published: PLOS ONE",appendLF=TRUE)
+    packageStartupMessage("# Published: PLOS ONE 2016, 11(6):1-15",appendLF=TRUE)
     packageStartupMessage("# Supported by the Council of Science and Technology (CONACYT)", appendLF=TRUE)
-    packageStartupMessage("# Type 'help(sommer)' for summary information",appendLF=TRUE)
     packageStartupMessage("# Type 'vignette('sommer')' for a short tutorial",appendLF=TRUE)
     packageStartupMessage("# Type 'citation('sommer')' to know how to cite sommer",appendLF=TRUE)
     packageStartupMessage(paste("## ========================================================= ## "),appendLF=TRUE)
-    packageStartupMessage("PLEASE UPDATE 'sommer' EVERY MONTH FOR NEW FEATURES USING",appendLF=TRUE)
-    packageStartupMessage(paste("install.packages('sommer') -- your version: ", sommer.version, ". ",sep=""),appendLF=TRUE)
+    packageStartupMessage("UPDATE 'sommer' EVERY MONTH USING 'install.packages('sommer')'",appendLF=TRUE)
     
     #if(yyy > current){ # yyy < current in CRAN
     #  packageStartupMessage(paste("Version",current,"is now available."),appendLF=TRUE) # version current
